@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -40,13 +37,16 @@
 
 enum {
     kHTBridgeSelfDevice = 0,
+    kPCIEBridgeSelfDevice = 0,
     kPCIBridgeSelfDevice = 11
 };
 
 enum {
   kMacRISCHTAddressSelect 	= 0x80,
   kMacRISCPCIAddressSelect 	= 0x48,
-  kMacRISCPCIModeSelect		= 0x50,
+  kMacRISCPCIEAddressSelect 	= 0xFC,
+  kMacRISCPCIEBridgeRegs		= 0x40,
+  kMacRISCPCIModeSelect			= 0x50,
   kMacRISCPCIModeSelectRDGBit 	= 0x00080000,
   kMacRISCPCIModeSelectWCBit    = 0x00100000
 };
@@ -150,6 +150,58 @@ public:
     virtual IOPCIAddressSpace getBridgeSpace( void );
 };
 
+class AppleMacRiscPCIE : public IOPCIBridge
+{
+    OSDeclareDefaultStructors(AppleMacRiscPCIE)
+
+protected:
+    IOSimpleLock	*	lock;
+    IOMemoryMap		*	hostRegsMap;
+    IOMemoryMap		*	configAtomicMap;
+    IODeviceMemory	*	ioMemory;
+
+    volatile UInt8	*	hostRegs;
+    volatile UInt8	*	configAtomic;
+    volatile UInt32	*	configAddrNA;
+    volatile UInt8	*	configDataNA;
+
+    UInt16			coarseAddressMask;
+    UInt16			fineAddressMask;
+    UInt8			primaryBus;
+	
+    UInt32			bridgeState[kMacRISCPCIEBridgeRegs];
+
+    inline bool configCycleAtomic( IOPCIAddressSpace space);
+    inline volatile UInt8 * setConfigSpace( IOPCIAddressSpace space, UInt8 offset );
+
+public:
+    virtual bool start(	IOService * provider );
+    virtual bool configure( IOService * provider );
+
+    virtual void free();
+
+    virtual IODeviceMemory * ioDeviceMemory( void );
+
+    virtual UInt32 configRead32( IOPCIAddressSpace space, UInt8 offset );
+    virtual void configWrite32( IOPCIAddressSpace space,
+					UInt8 offset, UInt32 data );
+    virtual UInt16 configRead16( IOPCIAddressSpace space, UInt8 offset );
+    virtual void configWrite16( IOPCIAddressSpace space,
+					UInt8 offset, UInt16 data );
+    virtual UInt8 configRead8( IOPCIAddressSpace space, UInt8 offset );
+    virtual void configWrite8( IOPCIAddressSpace space,
+					UInt8 offset, UInt8 data );
+
+    virtual IOPCIAddressSpace getBridgeSpace( void );
+
+    virtual IOReturn setDevicePowerState( IOPCIDevice * device,
+                                          unsigned long whatToDo );
+
+    virtual void saveBridgeState( void );
+
+    virtual void restoreBridgeState( void );
+};
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* Definitions of UniNorth Target config registers */
@@ -166,7 +218,9 @@ enum {
     kGART_2xRESET		= 0x00010000,
     kGART_DIS_SBA_DET		= 0x00020000,
     kGART_SYNC_MODE		= 0x00040000,
-    kGART_PERF_RD		= 0x00080000
+    kGART_PERF_RD		= 0x00080000,
+    kGART_B2B_GNT		= 0x00200000,
+    kGART_FAST_DDR		= 0x00400000
 };
 
 
